@@ -4,6 +4,7 @@ from __future__ import annotations
 import re
 
 from collections import abc
+from collections import Counter
 from collections import defaultdict
 
 from io import StringIO
@@ -26,6 +27,7 @@ from liquid.ast import ChildNode
 from liquid.ast import Node
 
 from liquid.context import Context
+from liquid.context import VariableCaptureContext
 from liquid.context import ReadOnlyChainMap
 
 from liquid.exceptions import TemplateTraversalError, LiquidInterrupt
@@ -37,6 +39,8 @@ from liquid.expression import Expression, StringLiteral
 from liquid.expression import Identifier
 from liquid.expression import Literal
 
+from liquid.output import LimitedStringIO
+
 
 if TYPE_CHECKING:  # pragma: no cover
     from liquid import Environment
@@ -71,6 +75,11 @@ class BoundTemplate:
     :type uptodate: Optional[Callable[[], bool]]
     """
 
+    # Subclass `BoundTemplate` and override `context_class` to use a subclass of
+    # `Context` when rendering templates.
+    context_class = Context
+    capture_context_class = VariableCaptureContext
+
     # pylint: disable=redefined-builtin, too-many-arguments
     def __init__(
         self,
@@ -95,18 +104,27 @@ class BoundTemplate:
 
         Accepts the same arguments as the :class:`dict` constructor.
         """
-        context = Context(self.env, globals=self.make_globals(dict(*args, **kwargs)))
-        buf = StringIO()
+        context = self.context_class(
+            self.env, globals=self.make_globals(dict(*args, **kwargs))
+        )
+        buf = self._get_buffer()
         self.render_with_context(context, buf)
         return buf.getvalue()
 
     async def render_async(self, *args: Any, **kwargs: Any) -> str:
         """An async version of :meth:`liquid.template.BoundTemplate.render`."""
-        context = Context(self.env, globals=self.make_globals(dict(*args, **kwargs)))
-        buf = StringIO()
+        context = self.context_class(
+            self.env, globals=self.make_globals(dict(*args, **kwargs))
+        )
+        buf = self._get_buffer()
         await self.render_with_context_async(context, buf)
         return buf.getvalue()
 
+    def _get_buffer(self) -> StringIO:
+        if self.env.output_stream_limit is None:
+            return StringIO()
+        return LimitedStringIO(limit=self.env.output_stream_limit)
+
     def render_with_context(
         self,
         context: Context,
@@ -226,7 +244,6 @@ class BoundTemplate:
             self.globals,
         )
 
-    # pylint: disable=no-self-use
     def make_partial_namespace(
         self,
         partial: bool,
@@ -255,7 +272,7 @@ class BoundTemplate:
         :param raise_for_failures: If ``True``, will raise an exception if an
             ``ast.Node`` or ``expression.Expression`` does not define a ``children()``
             method, or if a partial template can not be loaded. When ``False``, no
-            expection is raised and a mapping of failed nodes and expressions is
+            exception is raised and a mapping of failed nodes and expressions is
             available as the ``failed_visits`` property. A mapping of unloadable partial
             templates is stored in the ``unloadable_partials`` property.
         :type raised_for_failed_visits: bool
@@ -279,7 +296,7 @@ class BoundTemplate:
     async def analyze_async(
         self, follow_partials: bool = True, raise_for_failures: bool = True
     ) -> TemplateAnalysis:
-        """An async version of :meth:`analyse`."""
+        """An async version of :meth:`analyze`."""
         refs = await _TemplateVariableCounter(
             self,
             follow_partials=follow_partials,
@@ -294,6 +311,54 @@ class BoundTemplate:
             unloadable_partials=dict(refs.unloadable_partials),
         )
 
+    def analyze_with_context(
+        self, *args: Any, **kwargs: Any
+    ) -> ContextualTemplateAnalysis:
+        """Analyze a path through this template's syntax tree given some context data.
+
+        Unlike :meth:`analyze`, this form of template analysis does perform a render,
+        capturing template variables as we go.
+
+        Python Liquid does not currently support template introspection from within a
+        render context or ``Expression`` object. Meaning line numbers and template names
+        are not available. Only variable names are reported along with the number of
+        times they were referenced.
+
+        It's also, using this method, not currently possible to detect names added to a
+        block's scope. For example, ``forloop.index`` will be included in the results
+        object if referenced within a ``for`` loop block.
+
+        Accepts the same arguments as :meth:`render`.
+
+        :returns: Contextual analysis results.
+        :rtype: :class:`liquid.template.ContextualTemplateAnalysis`
+        """
+        context = self.capture_context_class(
+            self.env, globals=self.make_globals(dict(*args, **kwargs))
+        )
+        buf = self._get_buffer()
+        self.render_with_context(context, buf)
+        return ContextualTemplateAnalysis(
+            all_variables=dict(Counter(context.all_references)),
+            local_variables=dict(Counter(context.local_references)),
+            undefined_variables=dict(Counter(context.undefined_references)),
+        )
+
+    async def analyze_with_context_async(
+        self, *args: Any, **kwargs: Any
+    ) -> ContextualTemplateAnalysis:
+        """An async version of :meth:`analyze_with_context`."""
+        context = self.capture_context_class(
+            self.env, globals=self.make_globals(dict(*args, **kwargs))
+        )
+        buf = self._get_buffer()
+        await self.render_with_context_async(context, buf)
+        return ContextualTemplateAnalysis(
+            all_variables=dict(Counter(context.all_references)),
+            local_variables=dict(Counter(context.local_references)),
+            undefined_variables=dict(Counter(context.undefined_references)),
+        )
+
 
 class AwareBoundTemplate(BoundTemplate):
     """A `BoundTemplate` subclass that automatically includes a `TemplateDrop` in the
@@ -364,6 +429,38 @@ Refs = Dict[str, List[Tuple[str, int]]]
 ReferenceMap = DefaultDict[str, List[Tuple[str, int]]]
 
 
+# pylint: disable=too-few-public-methods
+class ContextualTemplateAnalysis:
+    """The result of analyzing a template's variables using
+    :meth:`BoundTemplate.analyze_with_context`.
+
+    Each of the following properties is a dictionary mapping variable names to the
+    number of times that variable was referenced.
+
+    :ivar all_variables: All variables references along a path through the template's
+        syntax tree.
+    :ivar local_variables: The names of variables assigned using the built-in ``assign``
+        ``capture``, ``increment`` or ``decrement`` tags, or any custom tag that uses
+        ``Context.assign()``.
+    :ivar undefined_variables: The names of variables that could not be resolved. If a
+        name is referenced before it is assigned, it will appear in ``undefined`` and
+        ``assigns``.
+    """
+
+    __slots__ = ("all_variables", "local_variables", "undefined_variables")
+
+    def __init__(
+        self,
+        *,
+        all_variables: Dict[str, int],
+        local_variables: Dict[str, int],
+        undefined_variables: Dict[str, int],
+    ) -> None:
+        self.all_variables = all_variables
+        self.local_variables = local_variables
+        self.undefined_variables = undefined_variables
+
+
 # pylint: disable=too-few-public-methods
 class TemplateAnalysis:
     """The result of analyzing a template's variables using
@@ -373,7 +470,7 @@ class TemplateAnalysis:
     two-tuples. Each tuple holds the location of a reference to the name as (<template
     name>, <line number>). If a name is referenced multiple times, it will appear
     multiple times in the list. If a name is referenced before it is "assigned", it will
-    appear in ``template_locals`` and ``template_globals``.
+    appear in ``local_variables`` and ``global_variables``.
 
     :ivar variables: All referenced variables, whether they are in scope or not.
         Including references to names such as ``forloop`` from the ``for`` tag.
@@ -426,7 +523,7 @@ class _TemplateVariableCounter:
         or ``expression.Expression`` does not define a ``children()`` method, or if a
         partial template can not be loaded.
 
-        When ``False``, no expection is raised and a mapping of failed nodes/expressions
+        When ``False``, no exception is raised and a mapping of failed nodes/expressions
         is available as the ``failed_visits`` property. A mapping of unloadable partial
         templates are stored in the ``unloadable_partials`` property.
     :type: raised_for_failed_visits: bool
@@ -476,7 +573,7 @@ class _TemplateVariableCounter:
     def analyze(self) -> _TemplateVariableCounter:
         """Traverse the template's syntax tree and count variables as we go.
 
-        It is not safe to call this method multuple times.
+        It is not safe to call this method multiple times.
         """
         for node in self.template.tree.statements:
             self._analyze(node)
