@@ -12,6 +12,8 @@ from liquid.ast import ChildNode, Node
 from liquid.context import Context
 from liquid.exceptions import TemplateTraversalError
 from liquid.expression import Expression
+from liquid.extra import add_inline_expression_tags
+from liquid.extra import WithTag
 from liquid.mode import Mode
 from liquid.stream import TokenStream
 from liquid.tag import Tag
@@ -909,3 +911,63 @@ class CountTemplateVariablesTestCase(TestCase):
                 failed_visits=expected_failed_visits,
                 raise_for_failures=True,
             )
+
+    def test_analyze_conditional_expression(self) -> None:
+        """Test that we can statically analyze non-standard conditional expressions."""
+        env = Environment()
+        add_inline_expression_tags(env)
+
+        template = env.from_string(r"{{ foo | upcase if a.b else bar || append: baz }}")
+
+        expected_template_globals = {
+            "foo": [("<string>", 1)],
+            "a.b": [("<string>", 1)],
+            "bar": [("<string>", 1)],
+            "baz": [("<string>", 1)],
+        }
+        expected_template_locals: Refs = {}
+        expected_refs = {
+            "foo": [("<string>", 1)],
+            "a.b": [("<string>", 1)],
+            "bar": [("<string>", 1)],
+            "baz": [("<string>", 1)],
+        }
+
+        self._test(
+            template,
+            expected_refs,
+            expected_template_locals,
+            expected_template_globals,
+        )
+
+    def test_analyze_with_tag(self) -> None:
+        """Test that we can statically analyze non-standard with tags."""
+        env = Environment()
+        env.add_tag(WithTag)
+
+        template = env.from_string(
+            r"{% with p: collection.products.first %}"
+            r"{{ p.title }}"
+            r"{% endwith %}"
+            r"{{ p.title }}"
+            r"{{ collection.products.first.title }}"
+        )
+
+        expected_template_globals = {
+            "collection.products.first": [("<string>", 1)],
+            "p.title": [("<string>", 1)],
+            "collection.products.first.title": [("<string>", 1)],
+        }
+        expected_template_locals: Refs = {}
+        expected_refs = {
+            "collection.products.first": [("<string>", 1)],
+            "collection.products.first.title": [("<string>", 1)],
+            "p.title": [("<string>", 1), ("<string>", 1)],
+        }
+
+        self._test(
+            template,
+            expected_refs,
+            expected_template_locals,
+            expected_template_globals,
+        )
